from distutils.core import setup

setup(
	name		= 'alpha_nest',
	version		= '1.3.0',
	py_modules	= ['alpha_nest'],
	author		= 'Alpha Diallo',
	author_email	= 'diallo.omr.alpha@gmail.com',
	url		= 'http://www.headfirstlabs.com',
	description	= 'A simple printer of nested lists',
)
